@@ -332,8 +332,10 @@ class Core:
     
     # Draws background on canvas
     def background(self, *args):
+        old_fill = self.canvas.fill_style
         argc = len(args)
-        if (argc == 3):
+
+        if argc == 3:
             if ((not type(args[0]) is int) or (not type(args[1]) is int) or (not type(args[2]) is int)):
                 raise TypeError("Enter Values between 0 and 255(integers only) for all 3 values")
             elif (not (args[0] >= 0 and args[0] <= 255) or not (args[1] >= 0 and args[1] <= 255) or not (
@@ -342,15 +344,13 @@ class Core:
             self.clear()
             self.fill_style(args[0], args[1], args[2])
             self.fill_rect(0, 0, self.width, self.height)
-
-        elif (argc == 1):
+        elif argc == 1:
             if (not type(args[0]) is str):
                 raise TypeError("Enter colour value in Hex i.e #000000 for black and so on")
             self.clear()
             self.fill_style(args[0])
             self.fill_rect(0, 0, self.width, self.height)
-
-        elif (argc == 4):
+        elif argc == 4:
             if ((not type(args[0]) is int) or (not type(args[1]) is int) or (not type(args[2]) is int) or (
             not type(args[3]) is float)):
                 raise TypeError("Enter Values between 0 and 255(integers only) for all 3 values")
@@ -361,6 +361,8 @@ class Core:
             self.clear()
             self.fill_style(args[0], args[1], args[2], args[3])
             self.fill_rect(0, 0, self.width, self.height)
+        
+        self.canvas.fill_style = old_fill
     
     ### Helper Functions ###
 
